@@ -298,7 +298,10 @@ class Zone(object):
     @property
     def num_points(self):
         """Number of elements in the associated data array."""
-        return reduce(lambda x, y: x*y,  self.shape, 1)
+        if self.type is ZoneType.Ordered:
+            return reduce(lambda x, y: x*y,  self.shape, 1)
+        else:
+            return self.shape[0]
 
     @property
     def shape(self):
